<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Moral
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class( 'home align-logo-center' ); ?>>
<?php do_action('wp_body_open'); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'restro-cafe-pro' ); ?></a>
    
    <div class="menu-overlay"></div>

    <?php $default = restro_cafe_pro_get_default_mods(); ?>

        <div id="header-menu">
            <div id="top-bar" class="relative">
                <button class="top-menu-toggle">
                    <svg viewBox="0 0 284.929 284.929" class="dropdown-icon icon-up">
                        <path d="M282.082,195.285L149.028,62.24c-1.901-1.903-4.088-2.856-6.562-2.856s-4.665,0.953-6.567,2.856L2.856,195.285C0.95,197.191,0,199.378,0,201.853c0,2.474,0.953,4.664,2.856,6.566l14.272,14.271c1.903,1.903,4.093,2.854,6.567,2.854c2.474,0,4.664-0.951,6.567-2.854l112.204-112.202l112.208,112.209c1.902,1.903,4.093,2.848,6.563,2.848c2.478,0,4.668-0.951,6.57-2.848l14.274-14.277c1.902-1.902,2.847-4.093,2.847-6.566C284.929,199.378,283.984,197.188,282.082,195.285z"/>
                    </svg>
                    <svg viewBox="0 0 129 129" class="dropdown-icon icon-down">
                        <path d="m121.3,34.6c-1.6-1.6-4.2-1.6-5.8,0l-51,51.1-51.1-51.1c-1.6-1.6-4.2-1.6-5.8,0-1.6,1.6-1.6,4.2 0,5.8l53.9,53.9c0.8,0.8 1.8,1.2 2.9,1.2 1,0 2.1-0.4 2.9-1.2l53.9-53.9c1.7-1.6 1.7-4.2 0.1-5.8z"/>
                    </svg>
                </button>

                <div class="wrapper">
                <?php  $phone_num = get_theme_mod( 'restro_cafe_pro_header_phone', $default['restro_cafe_pro_header_phone'] );
                        $location = get_theme_mod( 'restro_cafe_pro_header_location', $default['restro_cafe_pro_header_location'] ); ?>
                    <div class="<?php echo ( has_nav_menu( 'social' ) &&( (!empty($phone_num)) || (!empty($location)) ) )? 'col-2' : 'col-1'; ?> clear">
                    <?php if (!empty($location) || !empty($phone_num) ) : ?>
                            <div class="hentry">
                                <ul class="contact-info clear">
                                    <?php 
                                    if ( $location ) : ?>
                                        <li class="message">
                                            
                                            <?php echo restro_cafe_pro_get_svg( array( 'icon' => 'places' ) ); ?>
                                            <span><?php echo esc_html( $location ); ?></span>
                                            
                                        </li>
                                    <?php endif;
                                    if ( $phone_num ) : 
                                        ?>
                                        <li class="phone">
                                            <a href="tel:<?php echo esc_html($phone_num ); ?>">
                                            <?php echo restro_cafe_pro_get_svg( array( 'icon' => 'phone' ) ); ?>
                                            <span><?php echo esc_html( $phone_num ); ?></span>
                                            </a>
                                        </li>
                                    <?php endif; ?>
                                </ul><!-- .contact-info -->
                            </div><!-- .hentry -->
                         <?php endif;
                        if ( has_nav_menu( 'social' ) ) : ?>
                            <div class="hentry">
                                <div class="secondary-menu">
                                    <ul class="social-icons">
                                        <li>
                                        <?php
                                            wp_nav_menu( array(
                                                'theme_location' => 'social',
                                                'menu_class'     => 'social-icons',
                                                'container'     => '',
                                                'container_class' => '',
                                                'depth'          => 1,
                                                'link_before'    => '<span class="screen-reader-text">',
                                                'link_after'     => '</span>' . restro_cafe_pro_get_svg( array( 'icon' => 'chain' ) ),
                                            ) ); ?>   
                                        </li>
                                    </ul>
                                </div><!-- .secondary-menu -->
                            </div><!-- .hentry -->
                      <?php  endif; ?>
                    </div><!-- .col-2 -->
                </div><!-- .wrapper -->
            </div><!-- #top-bar -->

            <header id="masthead" class="site-header" role="banner">
                <div class="wrapper">
                    <div class="site-branding">
                        <?php if ( has_custom_logo() ) : ?>
                            <div class="site-logo">
                                <?php the_custom_logo(); ?>
                            </div><!-- .site-logo -->
                        <?php endif; ?>
                        <div id="site-identity">
                            <?php
                            if ( is_front_page() || is_archive() || is_home() || is_search() ) : ?>
                                <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                            <?php else : ?>
                                <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                            <?php
                            endif;

                            $description = get_bloginfo( 'description', 'display' );
                            if ( $description || is_customize_preview() ) : ?>
                                <p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
                            <?php
                            endif; ?>
                        </div><!-- .site-branding -->
                    </div>

                    <?php if ( has_nav_menu( 'primary' ) ) : ?>
                        <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Primary Menu', 'restro-cafe-pro' );?>">

                                <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
                                    <span class="menu-label"><?php esc_html_e( 'Menu', 'restro-cafe-pro' );?></span>
                                    <svg viewBox="0 0 40 40" class="icon-menu">
                                        <g>
                                            <rect y="7" width="40" height="2"/>
                                            <rect y="19" width="40" height="2"/>
                                            <rect y="31" width="40" height="2"/>
                                        </g>
                                    </svg>
                                    <svg viewBox="0 0 612 612" class="icon-close">
                                        <polygon points="612,36.004 576.521,0.603 306,270.608 35.478,0.603 0,36.004 270.522,306.011 0,575.997 35.478,611.397 
                                        306,341.411 576.521,611.397 612,575.997 341.459,306.011"/>
                                    </svg>
                                </button>
                                <?php
                                    wp_nav_menu( array(
                                    'theme_location' => 'primary',
                                    'menu_id'        => 'primary-menu',
                                    'menu_class'     => 'menu nav-menu',
                                    
                                ) );
                                     ?>
                        </nav><!-- #site-navigation -->
                    <?php elseif( current_user_can( 'edit_theme_options' ) ): ?>
                        <nav class="main-navigation" id="site-navigation">
                            <ul id="primary-menu" class="menu nav-menu">
                                <li><a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>"><?php echo esc_html__( 'Add a menu', 'restro-cafe-pro' );?></a></li>
                            </ul>
                        </nav>
                    <?php endif; ?> 
                </div><!-- .wrapper -->
            </header><!-- #masthead -->
        </div><!-- .header-menu -->



    
