<?php
/**
 * Blog section section
 */
// Blog section section
$wp_customize->add_section(
	'restro_cafe_pro_blog_section',
	array(
		'title' => esc_html__( 'Blog section', 'restro-cafe-pro' ),
		'description' => esc_html__( 'Recommended image ratio: 4:3', 'restro-cafe-pro' ),
		'panel' => 'restro_cafe_pro_home_panel',
	)
);

// Blog section enable settings
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
		'default' => 'recent-posts'
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Content type:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'restro-cafe-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'restro-cafe-pro' ),
				'recent-posts' => esc_html__( 'Recent Posts', 'restro-cafe-pro' ),
				'cat' => esc_html__( 'Category', 'restro-cafe-pro' ),
				'post' => esc_html__( 'Post', 'restro-cafe-pro' ),
		 	)
	)
);

// Blog section title setting
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => $default['restro_cafe_pro_blog_section_title'],
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section_title',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Title:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_blog_section_not_disabled'
	)
);

$wp_customize->selective_refresh->add_partial( 
	'restro_cafe_pro_blog_section_title', 
	array(
        'selector'            => '#latest-news .section-title',
		'render_callback'     => 'restro_cafe_pro_blog_section_partial_title',
	) 
);

// Blog section sub title setting
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section_sub_title',
	array(
		'sanitize_callback' => 'sanitize_textarea_field',
		'default' => $default['restro_cafe_pro_blog_section_sub_title'],
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section_sub_title',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Sub Title:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_blog_section_not_disabled',
		'type'			=> 'textarea'
	)
);

$wp_customize->selective_refresh->add_partial( 
	'restro_cafe_pro_blog_section_sub_title', 
	array(
        'selector'            => '#latest-news .section-subtitle',
		'render_callback'     => 'restro_cafe_pro_blog_section_partial_sub_title',
	) 
);

// Blog section number setting
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section_num',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_number_range',
		'default' => 3,
		// 'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section_num',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Number of posts:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Min: 1 | Max: 6', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_blog_section_not_disabled',
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 1, 'max' => 6 ),
	)
);

// Blog section category setting
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section_cat',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section_cat',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Category:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'The button will be linked to the selected category\'s archive link automatically.', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_blog_section_cat',
		'type'			=> 'select',
		'choices'		=> restro_cafe_pro_get_post_cat_choices(),
	)
);

$restro_cafe_pro_blog_section_num = get_theme_mod( 'restro_cafe_pro_blog_section_num', 3 );
for ( $i=1; $i <= $restro_cafe_pro_blog_section_num; $i++ ) { 
	// Popular post setting
	$wp_customize->add_setting(
		'restro_cafe_pro_blog_section_post_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_blog_section_post_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_blog_section',
			'label'			=> esc_html__( 'Post ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_blog_section_post',
			'type'			=> 'select',
			'choices'		=> restro_cafe_pro_get_post_choices(),
		)
	);
}


// Blog section button setting
$wp_customize->add_setting(
	'restro_cafe_pro_blog_section_btn_txt',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => $default['restro_cafe_pro_blog_section_btn_txt'],
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_blog_section_btn_txt',
	array(
		'section'		=> 'restro_cafe_pro_blog_section',
		'label'			=> esc_html__( 'Button text:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_blog_section_not_disabled'
	)
);

$wp_customize->selective_refresh->add_partial( 
	'restro_cafe_pro_blog_section_btn_txt', 
	array(
        'selector'            => '#latest-news .more-blog-posts span',
		'render_callback'     => 'restro_cafe_pro_blog_section_partial_btn_txt',
	) 
);