<?php
/**
 * Category tab section
 */
// Category tab section
$wp_customize->add_section(
	'restro_cafe_pro_cat_tab',
	array(
		'title' => esc_html__( 'Category tab', 'restro-cafe-pro' ),
		'description' => esc_html__( 'Recommended image ratio: 2:3', 'restro-cafe-pro' ),
		'panel' => 'restro_cafe_pro_home_panel',
	)
);

if ( restro_cafe_pro_is_woocommerce_activated() ) :
	// Category tab enable settings
	$wp_customize->add_setting(
		'restro_cafe_pro_cat_tab_enable',
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_cat_tab_enable',
		array(
			'section'		=> 'restro_cafe_pro_cat_tab',
			'label'			=> esc_html__( 'Enable category tab.', 'restro-cafe-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category Tab section title setting
	$wp_customize->add_setting(
		'restro_cafe_pro_category_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['restro_cafe_pro_category_section_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_category_section_title',
		array(
			'section'		=> 'restro_cafe_pro_cat_tab',
			'label'			=> esc_html__( 'Title:', 'restro-cafe-pro' ),
			'active_callback' => 'restro_cafe_pro_if_category_tab_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'restro_cafe_pro_category_section_title', 
		array(
	        'selector'            => '#shop-now .section-title',
			'render_callback'     => 'restro_cafe_pro_category_section_partial_title',
    	) 
    );

    // Category Tab section sub title setting
	$wp_customize->add_setting(
		'restro_cafe_pro_category_section_sub_title',
		array(
			'sanitize_callback' => 'sanitize_textarea_field',
			'default' => $default['restro_cafe_pro_category_section_sub_title'],
			'transport'	=> 'postMessage',
		)
	);
	$wp_customize->add_control(
	'restro_cafe_pro_category_section_sub_title',
	array(
		'section'		=> 'restro_cafe_pro_cat_tab',
		'label'			=> esc_html__( 'Sub Title:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_category_tab_not_disabled',
		'type'			=> 'textarea'
	)
	);

	$wp_customize->selective_refresh->add_partial( 
		'restro_cafe_pro_category_section_sub_title', 
		array(
	        'selector'            => '#shop-now .section-subtitle',
			'render_callback'     => 'restro_cafe_pro_category_section_partial_sub_title',
    	) 
    );

	// Category tab number setting
	$wp_customize->add_setting(
		'restro_cafe_pro_cta_tab_num',
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_number_range',
			'default' => 6,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_cta_tab_num',
		array(
			'section'		=> 'restro_cafe_pro_cat_tab',
			'label'			=> esc_html__( 'Number of category tabs:', 'restro-cafe-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 6', 'restro-cafe-pro' ),
			'active_callback' => 'restro_cafe_pro_if_category_tab_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 6 ),
		)
	);

	$cat_tab_num = get_theme_mod( 'restro_cafe_pro_cta_tab_num', 6 );
	for ( $i=1; $i <= $cat_tab_num; $i++ ) { 
		// Slider product category setting
		$wp_customize->add_setting(
			'restro_cafe_pro_cat_tab_cat_' . $i,
			array(
				'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'restro_cafe_pro_cat_tab_cat_' . $i,
			array(
				'section'		=> 'restro_cafe_pro_cat_tab',
				'label'			=> esc_html__( 'Product category ', 'restro-cafe-pro' ) . $i,
				'type'			=> 'select',
				'choices'		=> restro_cafe_pro_get_woo_product_cat(),
				'active_callback' => 'restro_cafe_pro_if_category_tab_not_disabled'
			)
		);
	}
else: 
	// Testimonial number separator setting
	$wp_customize->add_setting(
		'restro_cafe_pro_cta_woo_install',
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Restro_Cafe_Pro_Multi_Custom_Control( 
		$wp_customize,
		'restro_cafe_pro_cta_woo_install',
			array(
				'section'		=> 'restro_cafe_pro_cat_tab',
				'type'			=> 'store-mall-custom',
				'content' => sprintf( esc_html__( '%1$sInstall & Activate WooCommerce%2$s for this section to work.%3$s', 'restro-cafe-pro' ), '<h3><a target="_blank" href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ) . '">', '</a>', '</h3>' ),
			)
		)
	);
endif;





// Category Tab enable settings
$wp_customize->add_setting(
	'restro_cafe_pro_category',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
		'default' => 'cat'
	)
);
$choices =  array( 
	'disable' => esc_html__( '--Disable--', 'restro-cafe-pro' ),
	'cat' => esc_html__( 'Category', 'restro-cafe-pro' ),
	);
if ( restro_cafe_pro_is_woocommerce_activated() ) {
		$choices['product-cat'] = esc_html__( 'Product category ( Show categories )', 'restro-cafe-pro' );
	}

$wp_customize->add_control(
	'restro_cafe_pro_category',
	array(
		'section'		=> 'restro_cafe_pro_category',
		'label'			=> esc_html__( 'Content type:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'restro-cafe-pro' ),
		'type'			=> 'select',
		'choices'		=> $choices,
	)
);


for ( $i=1; $i <= 4; $i++ ) { 

	// Category Tab category setting
	$wp_customize->add_setting(
		'restro_cafe_pro_category_cat_'. $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_category_cat_'. $i,
		array(
			'section'		=> 'restro_cafe_pro_category',
			'label'			=> esc_html__( 'Category:', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_category_cat',
			'type'			=> 'select',
			'choices'		=> restro_cafe_pro_get_post_cat_choices(),
		)
	);

	if ( restro_cafe_pro_is_woocommerce_activated () ) {
		// Category Tab product category setting
		$wp_customize->add_setting(
			'restro_cafe_pro_category_product_cat_' . $i,
			array(
				'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'restro_cafe_pro_category_product_cat_' . $i,
			array(
				'section'		=> 'restro_cafe_pro_category',
				'label'			=> esc_html__( 'Product category ', 'restro-cafe-pro' ) . $i,
				'type'			=> 'select',
				'choices'		=> restro_cafe_pro_get_woo_product_cat(),
				'active_callback' => 'restro_cafe_pro_if_category_product_cat'
			)
		);	
	}
}