<?php
/**
 * Services section
 */
// Services section
$wp_customize->add_section(
	'restro_cafe_pro_services',
	array(
		'title' => esc_html__( 'Services', 'restro-cafe-pro' ),
		'panel' => 'restro_cafe_pro_home_panel',
	)
);

// Category Tab section title setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['restro_cafe_pro_services_section_title'],
			'transport'	=> 'refresh',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_section_title',
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'Title:', 'restro-cafe-pro' ),
			'active_callback' => 'restro_cafe_pro_if_services_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'restro_cafe_pro_services_section_title', 
		array(
	        'selector'            => '#shop-now .section-title',
			'render_callback'     => 'restro_cafe_pro_services_section_partial_title',
    	) 
    );

    // Category Tab section sub title setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_section_subtitle',
		array(
			'sanitize_callback' => 'sanitize_textarea_field',
			'default' => $default['restro_cafe_pro_services_section_subtitle'],
			'transport'	=> 'refresh',
		)
	);
	$wp_customize->add_control(
	'restro_cafe_pro_services_section_subtitle',
	array(
		'section'		=> 'restro_cafe_pro_services',
		'label'			=> esc_html__( 'Sub Title:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_services_not_disabled',
		'type'			=> 'textarea'
	)
	);

	$wp_customize->selective_refresh->add_partial( 
		'restro_cafe_pro_services_section_subtitle', 
		array(
	        'selector'            => '#shop-now .section-subtitle',
			'render_callback'     => 'restro_cafe_pro_services_section_partial_sub_title',
    	) 
    );

// Services enable settings
$wp_customize->add_setting(
	'restro_cafe_pro_services',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
		'default' => 'custom'
	)
);
$choices =  array( 
				'disable' => esc_html__( '--Disable--', 'restro-cafe-pro' ),
				'post' => esc_html__( 'Post', 'restro-cafe-pro' ),
				'page' => esc_html__( 'Page', 'restro-cafe-pro' ),
				'cat' => esc_html__( 'Category', 'restro-cafe-pro' ),
				'custom' => esc_html__( 'Custom', 'restro-cafe-pro' ),
		 	);

$wp_customize->add_control(
	'restro_cafe_pro_services',
	array(
		'section'		=> 'restro_cafe_pro_services',
		'label'			=> esc_html__( 'Content type:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'restro-cafe-pro' ),
		'type'			=> 'select',
		'choices'		=> $choices,
	)
);

// Services number setting
$wp_customize->add_setting(
	'restro_cafe_pro_services_num',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_number_range',
		'default' => 3,
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_services_num',
	array(
		'section'		=> 'restro_cafe_pro_services',
		'label'			=> esc_html__( 'Number of services:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Min: 1 | Max: 9', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_services_not_disabled',
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 1, 'max' => 9 ),
	)
);

// Services number separator setting
$wp_customize->add_setting(
	'restro_cafe_pro_services_num_separator',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
	)
);

$wp_customize->add_control(
	new Restro_Cafe_Pro_Multi_Custom_Control( 
	$wp_customize,
	'restro_cafe_pro_services_num_separator',
		array(
			'section'		=> 'restro_cafe_pro_services',
			'active_callback' => 'restro_cafe_pro_if_services_not_disabled',
			'type'			=> 'restro-cafe-pro-separator',
		)
	)
);

// Services category setting
$wp_customize->add_setting(
	'restro_cafe_pro_services_cat',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_services_cat',
	array(
		'section'		=> 'restro_cafe_pro_services',
		'label'			=> esc_html__( 'Category:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_services_cat',
		'type'			=> 'select',
		'choices'		=> restro_cafe_pro_get_post_cat_choices(),
	)
);



$services_num = get_theme_mod( 'restro_cafe_pro_services_num', 3 );
for ( $i=1; $i <= $services_num; $i++ ) { 

	// Services icon setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_icons_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_icons_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'icon ', 'restro-cafe-pro' ) . $i,
			'description' => sprintf( __('Please input icon as eg: fa-archive. Find Font-awesome icons %1$shere%2$s', 'restro-cafe-pro'), '<a href="' . esc_url( 'https://fontawesome.com/v4.7.0/cheatsheet/' ) . '" target="_blank">', '</a>' ),
			'active_callback' => 'restro_cafe_pro_if_services_not_disabled',
			'type'			=> 'text'
		)
	);
	 // Services custom content setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_custom_title_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['restro_cafe_pro_services_custom_title'],

		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_custom_title_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'Title ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_services_custom',
			'type'			=> 'text'
		)
	);

    // Services custom content setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_custom_content_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
			'default' => $default['restro_cafe_pro_services_custom_content'],
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_custom_content_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'Content ', 'restro-cafe-pro' ) . $i,
			'description'			=> esc_html__( 'HTML Allowed', 'restro-cafe-pro' ),
			'active_callback' => 'restro_cafe_pro_if_services_custom',
			'type'			=> 'textarea'
		)
	);

	// Services post setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_post_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_post_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'Post ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_services_post',
			'type'			=> 'select',
			'choices'		=> restro_cafe_pro_get_post_choices(),
		)
	);
	
	// Services page setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_page_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_services_page_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_services',
			'label'			=> esc_html__( 'Page ', 'restro-cafe-pro' ) . $i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'restro_cafe_pro_if_services_page'
		)
	);
	
	// Services custom separator setting
	$wp_customize->add_setting(
		'restro_cafe_pro_services_custom_separator_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Restro_Cafe_Pro_Multi_Custom_Control( 
		$wp_customize,
		'restro_cafe_pro_services_custom_separator_' . $i,
			array(
				'section'		=> 'restro_cafe_pro_services',
				'active_callback' => 'restro_cafe_pro_if_services_not_disabled',
				'type'			=> 'restro-cafe-pro-separator',
			)
		)
	);
}