<?php
/**
 * Testimonial section
 */
// Testimonial section
$wp_customize->add_section(
	'restro_cafe_pro_testimonial',
	array(
		'title' => esc_html__( 'Testimonial', 'restro-cafe-pro' ),
		'panel' => 'restro_cafe_pro_home_panel',
	)
);

// Testimonial enable settings
$wp_customize->add_setting(
	'restro_cafe_pro_testimonial',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
		'default' => 'custom'
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_testimonial',
	array(
		'section'		=> 'restro_cafe_pro_testimonial',
		'label'			=> esc_html__( 'Content type:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'restro-cafe-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'restro-cafe-pro' ),
				'post' => esc_html__( 'Post', 'restro-cafe-pro' ),
				'page' => esc_html__( 'Page', 'restro-cafe-pro' ),
				'cat' => esc_html__( 'Category', 'restro-cafe-pro' ),
				'custom' => esc_html__( 'Custom', 'restro-cafe-pro' ),
		 	)
	)
);



// Testimonial number setting
$wp_customize->add_setting(
	'restro_cafe_pro_testimonial_num',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_number_range',
		'default' => 3,
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_testimonial_num',
	array(
		'section'		=> 'restro_cafe_pro_testimonial',
		'label'			=> esc_html__( 'Number of testimonial:', 'restro-cafe-pro' ),
		'description'			=> esc_html__( 'Min: 1 | Max: 9', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_testimonial_not_disabled',
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 1, 'max' => 9 ),
	)
);

// Testimonial number separator setting
$wp_customize->add_setting(
	'restro_cafe_pro_testimonial_num_separator',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
	)
);

$wp_customize->add_control(
	new Restro_Cafe_Pro_Multi_Custom_Control( 
	$wp_customize,
	'restro_cafe_pro_testimonial_num_separator',
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'active_callback' => 'restro_cafe_pro_if_testimonial_not_disabled',
			'type'			=> 'restro-cafe-pro-separator',
		)
	)
);

// Testimonial category setting
$wp_customize->add_setting(
	'restro_cafe_pro_testimonial_cat',
	array(
		'sanitize_callback' => 'restro_cafe_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'restro_cafe_pro_testimonial_cat',
	array(
		'section'		=> 'restro_cafe_pro_testimonial',
		'label'			=> esc_html__( 'Category:', 'restro-cafe-pro' ),
		'active_callback' => 'restro_cafe_pro_if_testimonial_cat',
		'type'			=> 'select',
		'choices'		=> restro_cafe_pro_get_post_cat_choices(),
	)
);

$testimonial_num = get_theme_mod( 'restro_cafe_pro_testimonial_num', 3 );
for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	// Testimonial custom image setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_image_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'restro_cafe_pro_testimonial_image_' . $i,
			array(
				'section'		=> 'restro_cafe_pro_testimonial',
				'label'			=> esc_html__( 'Image ', 'restro-cafe-pro' ) . $i,
				'active_callback' => 'restro_cafe_pro_if_testimonial_custom',
			)
		)
	);

	// Testimonial custom name setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_custom_name_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['restro_cafe_pro_testimonial_custom_name'],
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_custom_name_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Title ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_testimonial_custom'
		)
	);

	// Testimonial custom sub title setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_custom_sub_title_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['restro_cafe_pro_testimonial_custom_sub_title'],
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_custom_sub_title_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Sub title ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_testimonial_not_disabled'
		)
	);

    // Testimonial custom content setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_custom_content_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
			'default' => $default['restro_cafe_pro_testimonial_custom_content'],
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_custom_content_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Content ', 'restro-cafe-pro' ) . $i,
			'description'			=> esc_html__( 'HTML Allowed ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_testimonial_custom',
			'type'			=> 'textarea'
		)
	);

	// Testimonial custom url setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_custom_url' . $i,
		array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_custom_url' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Url ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_testimonial_custom'
		)
	);

	// Testimonial post setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_post_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_post_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Post ', 'restro-cafe-pro' ) . $i,
			'active_callback' => 'restro_cafe_pro_if_testimonial_post',
			'type'			=> 'select',
			'choices'		=> restro_cafe_pro_get_post_choices(),
		)
	);

	// Testimonial page setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_page_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'restro_cafe_pro_testimonial_page_' . $i,
		array(
			'section'		=> 'restro_cafe_pro_testimonial',
			'label'			=> esc_html__( 'Page ', 'restro-cafe-pro' ) . $i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'restro_cafe_pro_if_testimonial_page'
		)
	);

	// Testimonial custom separator setting
	$wp_customize->add_setting(
		'restro_cafe_pro_testimonial_custom_separator_' . $i,
		array(
			'sanitize_callback' => 'restro_cafe_pro_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Restro_Cafe_Pro_Multi_Custom_Control( 
		$wp_customize,
		'restro_cafe_pro_testimonial_custom_separator_' . $i,
			array(
				'section'		=> 'restro_cafe_pro_testimonial',
				'active_callback' => 'restro_cafe_pro_if_testimonial_not_disabled',
				'type'			=> 'restro-cafe-pro-separator',
			)
		)
	);
}