<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function restro_cafe_pro_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	// When menu is sticky.
	$menu_transparent = get_theme_mod( 'restro_cafe_pro_make_menu_transparent', true );
	if ( $menu_transparent ) {
		$classes[] = 'menu-transparent';
	}

	// When menu is sticky.
	$menu_sticky = get_theme_mod( 'restro_cafe_pro_make_menu_sticky', false );
	if ( $menu_sticky ) {
		$classes[] = 'menu-sticky';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'restro_cafe_pro_theme_color_scheme', 'lite' );
	$classes[] = esc_attr( $color_scheme ) . '-version';
	
	// When global archive layout is checked.
	if ( is_archive() || restro_cafe_pro_is_latest_posts() || is_404() || is_search() ) {
		if ( restro_cafe_pro_is_woocommerce_activated() && ( is_woocommerce() || is_shop() || is_product_category() || is_product_tag() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$archive_sidebar = get_theme_mod( 'restro_cafe_pro_woo_global_archive_sidebar', 'right' ); 
				$classes[] = esc_attr( $archive_sidebar ) . '-sidebar';
			}
		} else {
			if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$archive_sidebar = get_theme_mod( 'restro_cafe_pro_archive_sidebar', 'right' ); 
				$classes[] = esc_attr( $archive_sidebar ) . '-sidebar';
			}
		}
	} else if ( is_single() ) { // When global post sidebar is checked.
		if ( restro_cafe_pro_is_woocommerce_activated() && ( is_woocommerce() || is_product() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$restro_cafe_pro_post_sidebar_meta = get_post_meta( get_the_ID(), 'restro-cafe-pro-select-sidebar', true );
		    	if ( ! empty( $restro_cafe_pro_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $restro_cafe_pro_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'restro_cafe_pro_woo_global_singular_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
			}
	    } else {
	    	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
	    		$restro_cafe_pro_post_sidebar_meta = get_post_meta( get_the_ID(), 'restro-cafe-pro-select-sidebar', true );
		    	if ( ! empty( $restro_cafe_pro_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $restro_cafe_pro_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'restro_cafe_pro_global_post_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
		    }
	    }
	} elseif ( restro_cafe_pro_is_frontpage_blog() || is_page() ) {
		if ( restro_cafe_pro_is_woocommerce_activated() && ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) ) {
			if ( ! is_active_sidebar( 'woocommerce' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				$restro_cafe_pro_post_sidebar_meta = get_post_meta( get_the_ID(), 'restro-cafe-pro-select-sidebar', true );
		    	if ( ! empty( $restro_cafe_pro_post_sidebar_meta ) ) {
					$classes[] = esc_attr( $restro_cafe_pro_post_sidebar_meta ) . '-sidebar';
		    	} else {
					$global_post_sidebar = get_theme_mod( 'restro_cafe_pro_woo_global_singular_layout', 'right' ); 
					$classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
		    	}
		    }
	    } else {
	    	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'no-sidebar';
			} else {
				if ( restro_cafe_pro_is_frontpage_blog() ) {
					$page_id = get_option( 'page_for_posts' );
				} else {
					$page_id = get_the_ID();
				}

		    	$restro_cafe_pro_page_sidebar_meta = get_post_meta( $page_id, 'restro-cafe-pro-select-sidebar', true );
				if ( ! empty( $restro_cafe_pro_page_sidebar_meta ) ) {
					$classes[] = esc_attr( $restro_cafe_pro_page_sidebar_meta ) . '-sidebar';
				} else {
					$global_page_sidebar = get_theme_mod( 'restro_cafe_pro_global_page_layout', 'right' ); 
					$classes[] = esc_attr( $global_page_sidebar ) . '-sidebar';
				}
			}
	    }
	} 

	// Site layout classes
	$site_layout = get_theme_mod( 'restro_cafe_pro_site_layout', 'wide' );
	$classes[] = esc_attr( $site_layout ) . '-layout';

	// Second Design
  	$classes[] = (get_theme_mod('restro_cafe_pro_design','default-design') == 'default-design') ? esc_attr('default-design') : esc_attr(get_theme_mod('restro_cafe_pro_design'));

	return $classes;
}
add_filter( 'body_class', 'restro_cafe_pro_body_classes' );

function restro_cafe_pro_post_classes( $classes ) {
	if ( restro_cafe_pro_is_page_displays_posts() ) {
		// Search 'has-post-thumbnail' returned by default and remove it.
		$key = array_search( 'has-post-thumbnail', $classes );
		unset( $classes[ $key ] );
		
		$archive_img_enable = get_theme_mod( 'restro_cafe_pro_enable_archive_featured_img', true );

		if( has_post_thumbnail() && $archive_img_enable ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}

  $classes[] = 'animated animatedFadeInUp';
  
	return $classes;
}
add_filter( 'post_class', 'restro_cafe_pro_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function restro_cafe_pro_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'restro_cafe_pro_archive_excerpt_length', 60 );
	return $length;
}
add_filter( 'excerpt_length', 'restro_cafe_pro_excerpt_length', 999 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function restro_cafe_pro_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'restro_cafe_pro_pingback_header' );

/**
 * Get an array of post id and title.
 * 
 */
function restro_cafe_pro_get_post_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'restro-cafe-pro' ) );
	$args = array( 'numberposts' => -1, );
	$posts = get_posts( $args );

	foreach ( $posts as $post ) {
		$id = $post->ID;
		$title = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of cat id and title.
 * 
 */
function restro_cafe_pro_get_post_cat_choices() {
  $choices = array( '' => esc_html__( '--Select--', 'restro-cafe-pro' ) );
	$cats = get_categories();

	foreach ( $cats as $cat ) {
		$id = $cat->term_id;
		$title = $cat->name;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of google fonts.
 * 
 */
function restro_cafe_pro_font_choices() {
	$font_family_arr = array();
	$font_family_arr[''] = esc_html__( '--Default--', 'restro-cafe-pro' );

	// Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/uploads/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
    	return false; // Bail early
    }
	// Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
    	foreach ( $data->items as $items => $fonts ) {
    		$family_str_arr = explode( ' ', $fonts->family );
    		$family_value = implode( '-', array_map( 'strtolower', $family_str_arr ) );
    		$font_family_arr[ $family_value ] = $fonts->family;
    	}
    }

    return apply_filters( 'restro_cafe_pro_font_choices', $font_family_arr );
}

/**
 * Checks to see if we're on the homepage or not.
 */
function restro_cafe_pro_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function restro_cafe_pro_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function restro_cafe_pro_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function restro_cafe_pro_is_page_displays_posts() {
	return ( restro_cafe_pro_is_frontpage_blog() || is_search() || is_archive() || restro_cafe_pro_is_latest_posts() );
}

/**
 * Shows a breadcrumb for all types of pages.  This is a wrapper function for the Breadcrumb_Trail class,
 * which should be used in theme templates.
 *
 * @since  1.0.0
 * @access public
 * @param  array $args Arguments to pass to Breadcrumb_Trail.
 * @return void
 */
function restro_cafe_pro_breadcrumb( $args = array() ) {
	$breadcrumb = apply_filters( 'breadcrumb_trail_object', null, $args );

	if ( ! is_object( $breadcrumb ) )
		$breadcrumb = new Breadcrumb_Trail( $args );

	return $breadcrumb->trail();
}

/**
 * Pagination in archive/blog/search pages.
 */
function restro_cafe_pro_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'restro_cafe_pro_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination( array(
            'prev_text'          => restro_cafe_pro_get_svg( array( 'icon' => 'left-arrow' ) ) . '<span class="meta-nav screen-reader-text">' . esc_html__( 'Previous', 'restro-cafe-pro' ).'</span>',
            'next_text'          => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Next', 'restro-cafe-pro' ) .'</span>' . restro_cafe_pro_get_svg( array( 'icon' => 'left-arrow' ) ),
        ) );
	} elseif ( 'older_newer' === $archive_pagination ) {
        the_posts_navigation( array(
            'prev_text'          => '<span class="icon">' . restro_cafe_pro_get_svg( array( 'icon' => 'left-arrow' ) ) . '</span><span>'. esc_html__( 'Older', 'restro-cafe-pro' ) .'</span>',
            'next_text'          => '<span class="icon">' . restro_cafe_pro_get_svg( array( 'icon' => 'left-arrow' ) ) . '</span><span>'. esc_html__( 'Newer', 'restro-cafe-pro' ) .'</span>',
        )  );
	}
}

function restro_cafe_pro_get_svg_by_url( $url = false ) {
	if ( ! $url ) {
		return false;
	}

	$social_icons = restro_cafe_pro_social_links_icons();

	foreach ( $social_icons as $attr => $value ) {
		if ( false !== strpos( $url, $attr ) ) {
			return restro_cafe_pro_get_svg( array( 'icon' => esc_attr( $value ) ) );
		}
	}
}

function restro_cafe_pro_custom_color_scheme() {
    
    $color = get_theme_mod( 'restro_cafe_pro_custom_color_scheme', '#f44240' );

    $h1_h6_font_family = explode( '-', get_theme_mod( 'restro_cafe_pro_h1_h6_font_option'  ) );
    $h1_h6_font_family = implode( ' ', array_map( 'ucfirst', $h1_h6_font_family ) );

    $body_font_family = explode( '-', get_theme_mod( 'restro_cafe_pro_body_font_option'  ) );
    $body_font_family = implode( ' ', array_map( 'ucfirst', $body_font_family ) );
    
    $custom_css = '';

    if ( 'custom' === get_theme_mod( 'restro_cafe_pro_color_scheme' ) ) {
    	$custom_css .= '
		.backtotop,
		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		#masthead,
		.pagination .page-numbers,
		.pagination .page-numbers.dots:hover,
		.pagination .page-numbers.dots:focus,
		.pagination .page-numbers.prev,
		.pagination .page-numbers.next,
		form.search-form button.search-submit,
		input[type="submit"],
		.reply a,
		.btn,
		.featured-content-wrapper .btn:hover,
		.featured-content-wrapper .btn:focus,
		.featured-content-wrapper .btn:not(:first-child):hover,
		.featured-content-wrapper .btn:not(:first-child):focus,
		.slick-arrow,
		.slick-dots li.slick-active button,
		.woocommerce #respond input#submit, 
		.woocommerce a.button, 
		.woocommerce button.button, 
		.woocommerce input.button,
		.woocommerce #respond input#submit.alt,
		.woocommerce a.button.alt, 
		.woocommerce button.button.alt, 
		.woocommerce input.button.alt,
		.woocommerce ul.products li.product a.added_to_cart.wc-forward,
		.woocommerce #respond input#submit.disabled, 
		.woocommerce #respond input#submit:disabled, 
		.woocommerce #respond input#submit:disabled[disabled], 
		.woocommerce a.button.disabled, 
		.woocommerce a.button:disabled, 
		.woocommerce a.button:disabled[disabled], 
		.woocommerce button.button.disabled, 
		.woocommerce button.button:disabled, 
		.woocommerce button.button:disabled[disabled], 
		.woocommerce input.button.disabled, 
		.woocommerce input.button:disabled, 
		.woocommerce input.button:disabled[disabled],
		.woocommerce span.onsale,
		.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
		.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a,
		.second-design .btn,
		.second-design .service-item-wrapper .entry-title:after {
       	    background-color: ' . esc_attr( $color ) . ';
       	}

       	button:hover,
		input[type="button"]:hover,
		input[type="reset"]:hover,
		input[type="submit"]:hover,
		button:focus,
		input[type="button"]:focus,
		input[type="reset"]:focus,
		input[type="submit"]:focus,
		button:active,
		input[type="button"]:active,
		input[type="reset"]:active,
		input[type="submit"]:active,
		a,
		.secondary-menu .apply-now,
		.site-title a:hover,
		.site-title a:focus,
		.main-navigation ul.nav-menu li.current-menu-item > a,
		.main-navigation ul.nav-menu li:hover > a,
		.main-navigation ul.nav-menu li:focus > a,
		.main-navigation a:hover,
		.main-navigation ul.nav-menu > li > a:hover,
		.navigation.post-navigation a:hover,
		.navigation.posts-navigation a:hover,
		.navigation.post-navigation a:focus,
		.navigation.posts-navigation a:focus,
		#secondary .cat-links a,
		#secondary a:hover,
		#secondary a:focus,
		.comment-meta .url:hover,
		.comment-meta .url:focus,
		.comment-metadata a:hover time,
		.comment-metadata a:focus time,
		.featured-content-wrapper .entry-title a:hover,
		.featured-content-wrapper .entry-title a:focus,
		.service-icon a,
		.service-item-wrapper .entry-title a:hover,
		.service-item-wrapper .entry-title a:focus,
		.dish-item-wrapper .entry-content,
		#call-to-action .section-subtitle,
		#shop-now ul.tabs li.active a,
		#shop-now .price,
		#about-us .section-title a:hover,
		#about-us .section-title a:focus,
		#our-menus .section-subtitle,
		.testimonial-details .entry-title a:hover,
		.testimonial-details .entry-title a:focus,
		.entry-title a:hover,
		.entry-title a:focus,
		.single-wrapper .entry-meta span a:hover, 
		.single-wrapper .entry-meta span a:focus,
		.single-wrapper .cat-links a,
		.single-wrapper .entry-meta span.byline a.fn:hover,
		.single-wrapper .entry-meta span.byline a.fn:focus,
		.single-wrapper .entry-meta > span a:hover,
		.single-wrapper .entry-meta > span a:focus,
		#colophon a:hover,
		#colophon a:focus,
		#colophon .site-info a,
		.second-design .section-subtitle {
       	    color: ' . esc_attr( $color ) . ';
       	}

       	.main-navigation ul.nav-menu li:hover > svg,
		.main-navigation ul.nav-menu li:focus > svg,
		.main-navigation li.menu-item-has-children:hover > a > svg,
		.main-navigation li.menu-item-has-children > a:hover > svg,
		.main-navigation li.menu-item-has-children > a:focus > svg,
		.main-navigation ul.nav-menu > li.current-menu-item > a > svg,
		.main-navigation li.search-menu a:hover svg,
		.main-navigation li.search-menu a.search-active:hover svg,
		.main-navigation ul.nav-menu li.search-menu:hover > a.search-active svg,
		.navigation.post-navigation a:hover svg,
		.navigation.posts-navigation a:hover svg,
		.navigation.post-navigation a:focus svg,
		.navigation.posts-navigation a:focus svg,
		.featured-content-wrapper .btn:hover .more-icon svg, 
		.featured-content-wrapper .btn:focus .more-icon svg {
		    fill: ' . esc_attr( $color ) . ';
		}

		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		textarea:focus,
		.pagination .page-numbers,
		.pagination .page-numbers.dots:hover,
		.pagination .page-numbers.dots:focus,
		.pagination .page-numbers.prev,
		.pagination .page-numbers.next,
		.slick-dots li button {
		    border-color: ' . esc_attr( $color ) . ';
		}

		@media screen and (min-width: 1024px) {
		    .menu-sticky #masthead.nav-shrink {
		        background-color: ' . esc_attr( $color ) . ';
		    }
		    .main-navigation ul.nav-menu ul li.current-menu-item > a,
		    .main-navigation ul.nav-menu ul li:hover > a,
		    .main-navigation ul.nav-menu ul li:focus > a,
		    .menu-transparent .main-navigation ul.nav-menu li.current-menu-item > a,
		    .menu-transparent .main-navigation ul.nav-menu li:hover > a,
		    .menu-transparent .main-navigation ul.nav-menu li > a:hover,
		    .menu-transparent .main-navigation ul.nav-menu li > a:focus {
		        color: ' . esc_attr( $color ) . ';
		    }
		    .main-navigation ul ul li.menu-item-has-children:hover > a > svg, 
		    .main-navigation ul ul li.menu-item-has-children > a:hover > svg,
		    .menu-transparent .main-navigation ul.nav-menu li.current-menu-item > a > svg,
		    .menu-transparent .main-navigation ul.nav-menu li:hover > a > svg,
		    .menu-transparent .main-navigation ul.nav-menu li > a:hover > svg,
		    .menu-transparent .main-navigation ul.nav-menu li > a:focus > svg {
		        fill: ' . esc_attr( $color ) . ';
		    }
		}

		@media screen and (max-width: 1023px) {
		    #masthead {
		        background-color: ' . esc_attr( $color ) . ';
		    }
		}';
	}
	$custom_css .= '
	/*----------------------------------------
   		Font Family
   	------------------------------------------*/
   	h1,
	h2,
	h3,
	h4,
	h5,
	h6,
	.post-navigation a, 
	.posts-navigation a,
	.single-post-wrapper span.tags-links,
	.single-post-wrapper span.cat-links,
	.blog-posts-wrapper .cat-links a,
	.blog-posts-wrapper .cat-links,
	.woocommerce div.product .woocommerce-tabs ul.tabs li a {
		font-family: ' . esc_attr( $h1_h6_font_family ) . ';
	}
	body,
	.single-post-wrapper span.tags-links a,
	.single-post-wrapper span.cat-links a,
	.blog-posts-wrapper span.cat-links,
	.blog-posts-wrapper span.cat-links a,
	.blog-posts-wrapper span.cat-links,
	.blog-posts-wrapper span.cat-links a {
		font-family: ' . esc_attr( $body_font_family ) . ';
	}
    ';
    wp_add_inline_style( 'restro-cafe-pro-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'restro_cafe_pro_custom_color_scheme' );

// Add auto p to the palces where get_the_excerpt is being called.
add_filter( 'get_the_excerpt', 'wpautop' );

/**
 * Get menu name by theme location
 */
function restro_cafe_pro_get_menu_nam_by_location( $menu_location ) {
    $locations = get_nav_menu_locations();
    $menu_obj = wp_get_nav_menu_object( $locations[ $menu_location ] );
    return $menu_obj->name;
}

if ( ! function_exists( 'restro_cafe_pro_is_woocommerce_activated' ) ) {
	/**
	 * Query WooCommerce activation
	 */
	function restro_cafe_pro_is_woocommerce_activated() {
		return class_exists( 'WooCommerce' ) ? true : false;
	}
}

if ( ! function_exists( 'restro_cafe_pro_is_yww_activate' ) ) {
	/**
	 * Check if YITH WooCommerce Wishlist is activated.
	 */
	function restro_cafe_pro_is_yww_activate() {
		return class_exists( 'YITH_WCWL' ) ? true : false;
	}
}

/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 */
/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 * @param  string $sidebar_id Sidebar widget area id.
 * @return int             Number of widgets in the sidebar
 */
function restro_cafe_pro_count_widgets( $sidebar_id = '' ) {
	if ( empty( $sidebar_id ) ) {
		return false;
	}
	// If loading from front page, consult $_wp_sidebars_widgets rather than options
	// to see if wp_convert_widget_settings() has made manipulations in memory.
	// global $_wp_sidebars_widgets;
	// if ( empty( $_wp_sidebars_widgets ) ) :
	// 	$_wp_sidebars_widgets = get_option( 'sidebars_widgets', array() );
	// endif;
	
	$sidebars_widgets_count = get_option( 'sidebars_widgets', array() );
	
	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) :
		$widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
		return $widget_count;
	else:
		return false;
	endif;
}