<?php
/**
 * Template part for displaying front page about.
 *
 * @package Moral
 */
// Get default  mods value.
$default = restro_cafe_pro_get_default_mods();

// Get the content type.
$about = get_theme_mod( 'restro_cafe_pro_about', 'custom' );


// Bail if the section is disabled.
if ( 'disable' === $about ) {
    return;
}

// Query if the content type is either post or page.
if (  in_array( $about, array( 'post', 'page' ) ) ) {

    if ( 'post' === $about ) {
        $id = get_theme_mod( 'restro_cafe_pro_about_post' );
    } else {
        $id = get_theme_mod( 'restro_cafe_pro_about_page' );
    }

    $query = new WP_Query( array( 'post_type' => $about, 'p' => absint( $id ) ) );

    if ( $query->have_posts() ) {
        while ( $query->have_posts() ) {
            $query->the_post();
            $img_url     = get_the_post_thumbnail_url( $id, 'large' );
            $about_title   = get_the_title();
            $content = get_the_content();
            $btn_url     = get_permalink();
        }
        wp_reset_postdata();
    }
} else {
    $about_title   = get_theme_mod( 'restro_cafe_pro_about_title', $default['restro_cafe_pro_about_title'] );
    $content = get_theme_mod( 'restro_cafe_pro_about_content', $default['restro_cafe_pro_about_content'] );
    $btn_url     = get_theme_mod( 'restro_cafe_pro_about_link', '#' );

    $img_url = get_theme_mod( 'restro_cafe_pro_about_image' );
}

// Get the common settings value  in custom, page and post.
$about_background_image = get_theme_mod( 'restro_cafe_pro_about_background_image');
$about_subtitle   = get_theme_mod( 'restro_cafe_pro_about_sub_title');
$btn_txt = get_theme_mod( 'restro_cafe_pro_about_btn_txt', $default['restro_cafe_pro_about_btn_txt'] );

?>


<div id="about-us" class="relative page-section">
    <div class="wrapper">
        <article class="has-post-thumbnail">
            <div class="featured-image" style="background-image: url('<?php echo esc_url($img_url); ?>');">
                <a href="<?php echo esc_url($btn_url ); ?>" class="post-thumbnail-link"></a>
            </div><!-- .featured-image -->

            <div class="entry-container">
                <?php if (!empty($about_title) || !empty($about_subtitle)): ?>
                    <div class="section-header">
                        <?php if (!empty($about_subtitle)): ?>
                            <p class="section-subtitle"><?php echo esc_html($about_subtitle); ?></p>
                        <?php endif ?>
                        <?php if (!empty($about_title)): ?>
                            <h2 class="section-title"><?php echo esc_html($about_title); ?></h2>
                        <?php endif ?>
                        
                    </div><!-- .section-header -->
                <?php endif ?>
                <?php if (!empty($content) ): ?>
                    <div class="entry-content">
                        <p><?php  echo wp_trim_words( $content, 50); ?></p>
                    </div><!-- .entry-content -->
                <?php endif ?>
                <?php if (!empty($btn_txt) || ! empty( $btn_url ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url($btn_url ); ?>" class="btn"><?php echo esc_html($btn_txt);?></a>
                </div><!-- .read-more -->
            <?php endif; ?>
            </div><!-- .entry-container -->
        </article>
    </div><!-- .wrapper -->
</div><!-- #about-us -->