<?php
/**
 * Template part for displaying front page blog section.
 *
 * @package Moral
 */

// Get default  mods value.
$blog_section = get_theme_mod( 'restro_cafe_pro_blog_section', 'recent-posts' );

if ( 'disable' === $blog_section ) {
	return;
}

$default = restro_cafe_pro_get_default_mods();

$img_position = get_theme_mod( 'restro_cafe_pro_blog_image_position', 'before-title' );
$btn_txt = get_theme_mod( 'restro_cafe_pro_blog_section_btn_txt', $default['restro_cafe_pro_blog_section_btn_txt'] );
?>

<div id="latest-posts" class="relative page-section same-background">
    <div class="wrapper">
        <div class="section-header">
        	<?php  
        	$section_title =  get_theme_mod( 'restro_cafe_pro_blog_section_title', $default['restro_cafe_pro_blog_section_title'] );
        	$section_sub_title =  get_theme_mod( 'restro_cafe_pro_blog_section_sub_title', $default['restro_cafe_pro_blog_section_sub_title'] );
        	
        	if ( ! empty( $section_sub_title ) ) : ?>
            	<p class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></p>
        	<?php endif; 
            if ( ! empty( $section_title ) ) : ?>
                <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            <?php endif; ?>

        </div><!-- .section-header -->

        <!-- supports col-1, col-2, col-3, col-4 -->
        <?php  
        $posts_per_page = get_theme_mod( 'restro_cafe_pro_blog_section_num', 3 );
        if ( $posts_per_page > 3 ) {
        	$class = 3;
        } else {
        	$class = $posts_per_page; 
        }
        ?>
        <div class="blog-archive-wrapper col-<?php echo esc_attr( $class ); ?> clear">
        	<?php  
        	$btn_link = get_permalink( get_option( 'page_for_posts' ) );

        	if ( 'recent-posts' === $blog_section ) {
            	$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
            		);
        	} elseif ( 'post' === $blog_section ) {
        		$id = array();
				for ( $i=1; $i <= $posts_per_page; $i++ ) { 
					$id[] = get_theme_mod( 'restro_cafe_pro_blog_section_post_' . $i );
				}
        		$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
						'post__in' => (array)$id,	
    					'orderby'	=> 'post__in',
            		);
        	} elseif ( 'cat' === $blog_section ) {
        		$cat_id = get_theme_mod( 'restro_cafe_pro_blog_section_cat' );
        		$btn_link = get_category_link( $cat_id );
        		$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
            			'cat' => $cat_id,
            		);
        	}

        	$query = new WP_Query( $args );

			if ( $query->have_posts() ) :
				while ( $query->have_posts() ) :
					$query->the_post(); 

						$class = ( has_post_thumbnail() ) ? 'has-post-thumbnail' : '';
						?> 
                        <article class="<?php echo esc_attr( $class );?>">
                            <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url('large') ?>');">
                                <a href="<?php the_permalink(); ?>" class="post-thumbnail-link"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <div class="entry-meta">
                                    <span class="posted-on">
                                        <span class="screen-reader-text"><?php esc_html_e('Posted on', 'restro-cafe-pro'); ?></span> 
                                        <?php restro_cafe_pro_posted_on();?>
                                    </span>
                                    <span class="cat-links">
                                       <?php the_category(); ?>
                                    </span><!-- .cat-links -->
                                </div><!-- .entry-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                   <?php the_excerpt(); ?>
                                </div><!-- .entry-content -->

                                <div class="read-more">
                                   <a href="<?php the_permalink(); ?>" class="more-link"><?php esc_html_e( 'Read More', 'restro-cafe-pro' ); ?>
                                </a>
                                </div><!-- .read-more -->
                            </div><!-- .entry-container -->
                        </article>

		        <?php endwhile; ?>
		        <?php wp_reset_postdata(); ?>
        	<?php endif; ?>
        </div><!-- .blog-posts-wrapper -->
        <?php if ( ! empty( $btn_txt ) ) : ?>
            <div class="view-all">
                <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-primary"><span><?php echo esc_html( $btn_txt );  ?></span></a>
            </div><!-- .more-link -->
        <?php endif; ?>
    </div><!-- .wrapper -->
</div><!-- #latest-posts -->
