<?php
/**
 * Template part for displaying front page cta.
 *
 * @package Moral
 */
// Get default  mods value.
$default = restro_cafe_pro_get_default_mods();

// Get the content type.
$cta = get_theme_mod( 'restro_cafe_pro_cta', 'custom' );


// Bail if the section is disabled.
if ( 'disable' === $cta ) {
	return;
}

// Query if the content type is either post or page.
if (  in_array( $cta, array( 'post', 'page' ) ) ) {

	if ( 'post' === $cta ) {
		$id = get_theme_mod( 'restro_cafe_pro_cta_post' );
	} else {
		$id = get_theme_mod( 'restro_cafe_pro_cta_page' );
	}

	$query = new WP_Query( array( 'post_type' => $cta, 'p' => absint( $id ) ) );

	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			$img_url     = get_the_post_thumbnail_url( $id, 'medium' );
			$cta_title   = get_the_title();
			$content = get_the_excerpt();
			$btn_url     = get_permalink();
		}
		wp_reset_postdata();
	}
} else {
	$cta_title   = get_theme_mod( 'restro_cafe_pro_cta_title', $default['restro_cafe_pro_cta_title'] );
	$content = get_theme_mod( 'restro_cafe_pro_cta_content', $default['restro_cafe_pro_cta_content'] );
	$btn_url     = get_theme_mod( 'restro_cafe_pro_cta_link', '#' );

	$img_url = get_theme_mod( 'restro_cafe_pro_cta_image' );
}

// Get the common settings value  in custom, page and post.
$cta_background_image = get_theme_mod( 'restro_cafe_pro_cta_background_image');
$cta_subtitle   = get_theme_mod( 'restro_cafe_pro_cta_sub_title');
$btn_txt = get_theme_mod( 'restro_cafe_pro_cta_btn_txt', $default['restro_cafe_pro_cta_btn_txt'] );

?>

<div id="call-to-action" class="relative page-section" style="background-image: url('<?php echo esc_url($cta_background_image); ?>');">
    <div class="overlay"></div>
    <div class="wrapper">
    	<?php if (!empty($cta_title) || !empty($cta_subtitle)): ?>
    		<div class="section-header">
	    		<?php if (!empty($cta_subtitle)): ?>
	    			<p class="section-subtitle"><?php echo esc_html($cta_subtitle); ?></p>
	    		<?php endif ?>
            	<?php if (!empty($cta_title)): ?>
            		<h2 class="section-title"><?php echo esc_html($cta_title); ?></h2>
            	<?php endif ?>
	            
	        </div><!-- .section-header -->
    	<?php endif ?>
       
    	<?php if (!empty($img_url)): ?>
    		<div class="offer-image">
	            <img src="<?php echo esc_url($img_url); ?>" alt="offer">
	        </div><!-- .offer-image -->
    	<?php endif ?>
        
    	<?php if (!empty($btn_txt) || ! empty( $btn_url ) ): ?>
    		<div class="order-now">
	            <a href="<?php echo esc_url($btn_url ); ?>" class="btn"><?php echo esc_html($btn_txt);?></a>
	        </div><!-- .order-now -->
    	<?php endif ?>
        
    </div><!-- .wrapper -->
</div><!-- #call-to-action -->
