<?php
/**
 * Template part for displaying front page menus.
 *
 * @package Moral
 */

// Get default  mods value.
$menus = get_theme_mod( 'restro_cafe_pro_menus', 'custom' );

if ( 'disable' === $menus ) {
    return;
}

$default = restro_cafe_pro_get_default_mods();
$menus_background = get_theme_mod( 'restro_cafe_pro_menus_section_background' );
$menus_title = get_theme_mod( 'restro_cafe_pro_menus_section_title', $default['restro_cafe_pro_popular_custom_title'] );
$menus_subtitle = get_theme_mod( 'restro_cafe_pro_menus_section_subtitle', $default['restro_cafe_pro_popular_custom_title'] );
$menus_num = get_theme_mod( 'restro_cafe_pro_menus_num', 6 );
$menus_readmore = get_theme_mod( 'restro_cafe_pro_menus_readmore_btn', $default['restro_cafe_pro_popular_custom_title'] );
$menus_readmore_url = get_theme_mod( 'restro_cafe_pro_menus_readmore_url' ); ?>

<div id="our-menus" class="relative page-section" style="background-image: url('<?php echo esc_url($menus_background); ?>');">
    <div class="overlay"></div>
    <div class="wrapper">
    <?php if (!empty($menus_title) || !empty($menus_subtitle)): ?>
    	<div class="section-header">
            <p class="section-subtitle"><?php echo esc_html($menus_subtitle); ?></p>
            <h2 class="section-title"><?php echo esc_html($menus_title); ?></h2>
        </div><!-- .section-header -->
    <?php endif ?>
        
    <div class="col-2 clear">
		<?php
		if (  in_array( $menus, array( 'post', 'page', 'cat' ) ) ) {

		    if ( 'cat' === $menus ) {
		        $cat_id = get_theme_mod( 'restro_cafe_pro_menus_cat' );
		        $args = array(
		            'cat' => $cat_id,   
		            'posts_per_page' => $menus_num,
		        );
		    } else {
		        $id = array();
		        for ( $i=1; $i <= $menus_num; $i++ ) { 
		            $id[] = get_theme_mod( "restro_cafe_pro_menus_{$menus}_" . $i );
		        }

		        $args = array(
		            'post_type' => $menus,
		            'post__in' => (array)$id,   
	                'orderby'   => 'post__in',
		            'posts_per_page' => $menus_num,
		            'ignore_sticky_posts' => true,
		        );
		    }

		    $query = new WP_Query( $args );
		    $i=1;
		    if ( $query->have_posts() ) :
		        while ( $query->have_posts() ) :
		            $query->the_post();
		            ?>
		            <article>
		                <div class="menu-item-wrapper">
		                    <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url('thumbnail') ?>');">
		                        <a href="<?php the_permalink(); ?>" class="post-thumbnail-link"></a>
		                    </div>
		                    <div class="entry-container">
		                        <header class="entry-header">
		                            <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
		                        </header>

		                        <div class="entry-content">
		                           <?php 
	                                $excerpt = get_the_content();
	                                 echo wp_trim_words( $excerpt, 20); 
                                 ?>
		                        </div><!-- .entry-content -->
		                    </div><!-- .entry-container -->
		                </div><!-- .menu-item-wrapper -->
		            </article>
		        <?php 
		    	endwhile;
		        wp_reset_postdata();
		    endif; 
		} elseif( 'custom' === $menus ) {
		    for ( $i=1; $i <= $menus_num; $i++ ) { 
		        $img_url = get_theme_mod( 'restro_cafe_pro_menus_image_' . $i );
		        $title   = get_theme_mod( 'restro_cafe_pro_menus_custom_title_' . $i, $default['restro_cafe_pro_menus_custom_title'] );
		        $content   = get_theme_mod( 'restro_cafe_pro_menus_custom_content_' . $i, $default['restro_cafe_pro_menus_custom_content'] );
		        $menus_price =  get_theme_mod( 'restro_cafe_pro_menus_custom_menus_price_' . $i, $default['restro_cafe_pro_menus_custom_price']);
		        $btn_url = get_theme_mod( 'restro_cafe_pro_menus_custom_link_' . $i, '#' );
		        
		        ?>
		        <article>
	                <div class="menu-item-wrapper">
	                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url );?>');">
	                        <a href="<?php echo esc_url($btn_url); ?>" class="post-thumbnail-link"></a>
	                    </div>
	                    <div class="entry-container">
	                        <header class="entry-header">
	                            <h2 class="entry-title"><a href="<?php echo esc_url($btn_url); ?>"><?php echo esc_html($title); ?></a></h2>
	                        </header>

	                        <div class="entry-content">
	                           <?php echo wp_kses_post( $content, $default['restro_cafe_pro_menus_custom_content'] ); ?>
	                        </div><!-- .entry-content -->
	                    </div><!-- .entry-container -->
	                    <?php if (!empty($menus_price)): ?>
	                    	<span class="price">
		                        <span class="woocommerce-Price-amount amount">
		                            <span class="woocommerce-Price-currencySymbol"><?php echo esc_html($menus_price); ?></span>
		                        </span>
		                    </span><!-- .price -->
	                    <?php endif ?>
	                    
	                </div><!-- .menu-item-wrapper -->
	            </article>
		<?php   
		    }
		} elseif( in_array( $menus, array( 'recent-products', 'product' ) ) ) {
			if ( 'product' ===  $menus ) {
	    		$product_ids = array();
	    		for ( $i=1; $i <= $menus_num; $i++ ) { 
	    	        $product_id = get_theme_mod( 'restro_cafe_pro_menus_product_' . $i );
	    	        if ( $product_id ) {
	    	        	$product_ids[] = $product_id;
	    	        }
	    	    }

	    	    $args = array( 'orderby'   => 'post__in', 'include' => $product_ids );
			} else {
	    	    $args = array( 'posts_per_page' => $menus_num );
			}
		    $products = wc_get_products( $args );
		    if ( $products ) :
		    	foreach ( $products as $product ) {
	    	       $url = $product->get_permalink();
	    	        $thumbnail_id = $product->get_image_id();
	    	        $img_url = wp_get_attachment_url( $thumbnail_id );
	    	        $name  = $product->get_name();

	    	        
	    	        ?>
	    	        <article>
		                <div class="menu-item-wrapper">
		                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url ); ?>');">
		                        <a href="<?php echo esc_url( $url ); ?>" class="post-thumbnail-link"></a>
		                    </div>
		                    <div class="entry-container">
		                        <header class="entry-header">
		                            <h2 class="entry-title"><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $name );?></a></h2>
		                        </header>

		                        <div class="entry-content">
		                          <p><?php 
		                          	$excerpt = $product->get_short_description();
	                                 echo wp_trim_words( $excerpt, 10);
		                            ?></p>
		                        </div><!-- .entry-content -->
		                    </div><!-- .entry-container -->
	                    	<span class="price">
		                        <span class="woocommerce-Price-amount amount">
		                            <span class="woocommerce-Price-currencySymbol"><?php echo $product->get_price_html(); ?></span>
		                        </span>
		                    </span><!-- .price -->
		                </div><!-- .menu-item-wrapper -->
		            </article>	    	        
		    	<?php
		    	}
		    endif;
		}  
		
		?>
		
	</div><!-- .wrapper -->
	<?php if (!empty($menus_readmore) && !empty($menus_readmore_url) ): ?>
			<div class="view-all">
	            <a href="<?php echo esc_url($menus_readmore_url); ?>" class="btn"><?php echo esc_html($menus_readmore); ?></a>
	        </div><!-- .view-all -->
		<?php endif ?>
</div><!-- #product-menus -->
</div>

