<?php
/**
 * Template part for displaying front page services.
 *
 * @package Moral
 */

// Get default  mods value.
$services = get_theme_mod( 'restro_cafe_pro_services', 'custom' );

if ( 'disable' === $services ) {
    return;
}

$default = restro_cafe_pro_get_default_mods();

$services_num = get_theme_mod( 'restro_cafe_pro_services_num', 3 );
$col_class = '';
if ( $services_num > 5 ) {
    if ( $services_num % 4 === 0 ) {
        $col_class = 4;
    } else {
        $col_class = 3;
    }
} else {
    $col_class = $services_num;
}
$services_section_title = get_theme_mod( 'restro_cafe_pro_services_section_title', $default['restro_cafe_pro_services_section_title'] );
$services_section_subtitle = get_theme_mod( 'restro_cafe_pro_services_section_subtitle', $default['restro_cafe_pro_services_section_subtitle'] );


?>


<div id="our-services" class="relative page-section same-background">
    <div class="wrapper">
        <?php if (!empty($services_section_title) || !empty($services_section_subtitle)) : ?>
            <div class="section-header">
                <?php if (!empty($services_section_subtitle)): ?>
                   <p class="section-subtitle"><?php echo esc_html($services_section_subtitle); ?></p> 
                <?php endif ?>
                <?php if (!empty($services_section_title)): ?>
                    <h2 class="section-title"><?php echo esc_html($services_section_title); ?></h2>  
                <?php endif ?>  
            </div><!-- .section-header -->
        <?php endif; ?>

        <!-- supports col-1, col-2,col-3, col-4 -->
        <div class="col-<?php echo esc_attr($col_class); ?> clear">
        <?php
        if (  in_array( $services, array( 'post', 'page', 'cat' ) ) ) {

            if ( 'cat' === $services ) {
                $cat_id = get_theme_mod( 'restro_cafe_pro_services_cat' );
                $args = array(
                    'cat' => $cat_id,   
                    'posts_per_page' => $services_num,
                );
            } else {
                $id = array();
                for ( $i=1; $i <= $services_num; $i++ ) { 
                    $id[] = get_theme_mod( "restro_cafe_pro_services_{$services}_" . $i );
                }

                $args = array(
                    'post_type' => $services,
                    'post__in' => (array)$id,   
                    'orderby'   => 'post__in',
                    'posts_per_page' => $services_num,
                    'ignore_sticky_posts' => true,
                );
            }

            $query = new WP_Query( $args );
            $i=1;
            if ( $query->have_posts() ) :
                while ( $query->have_posts() ) :
                    $query->the_post();
                    ?>
                    <article>
                        <div class="service-item-wrapper">
                            <?php
                            $services_post_icon= get_theme_mod( 'restro_cafe_pro_services_icons_' . $i ); if (!empty($services_post_icon)): ?>
                                <div class="service-icon">
                                <a href="<?php the_permalink(); ?>"><i class="fa <?php echo esc_attr($services_post_icon); ?>"></i></a>
                            </div><!-- .service-icon -->   
                            <?php endif ?>
                        
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <?php 
                                    $excerpt = get_the_content();
                                     echo wp_trim_words( $excerpt, 20); 
                                 ?>
                            </div><!-- .entry-content -->
                        </div><!-- .service-item-wrapper -->
                    </article>
                <?php $i++;
                endwhile;
                wp_reset_postdata();
            endif; 
        } else {
            for ( $i=1; $i <= $services_num; $i++ ) { 
                $title   = get_theme_mod( 'restro_cafe_pro_services_custom_title_' . $i, $default['restro_cafe_pro_services_custom_title'] );
                $content   = get_theme_mod( 'restro_cafe_pro_services_custom_content_' . $i, $default['restro_cafe_pro_services_custom_content'] );
                $url = get_theme_mod( 'restro_cafe_pro_services_custom_link_' . $i, '#' );
                $services_post_icon= get_theme_mod( 'restro_cafe_pro_services_icons_' . $i );

                
                ?>
                <article>
                    <div class="service-item-wrapper">
                        <?php if (!empty($services_post_icon)): ?>
                            <div class="service-icon">
                            <a href="<?php echo esc_url($url); ?>"><i class="fa <?php echo esc_attr($services_post_icon); ?>"></i></a>
                        </div><!-- .service-icon -->   
                        <?php endif ?>
                    
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($url); ?>"><?php echo esc_html($title); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <?php echo wp_kses_post( $content, $default['restro_cafe_pro_services_custom_content'] ); ?>
                        </div><!-- .entry-content -->
                    </div><!-- .service-item-wrapper -->
                </article>
        <?php   
            }
        }
        ?>
        </div><!-- .col-3 -->
    </div><!-- .wrapper -->
</div><!-- #our-services -->